# pygcgen
A python version of [GitHub Changelog Generator](https://github.com/skywinder/github-changelog-generator/tree/9483c5edcb6365698c7beebf819d86c1f7e5aeeb)

|
---

## Status

Tested on Win10 (64Bit) with Python 2.7 (32Bit, Stackless) and Python 3.5 (32Bit) and on Ubuntu 16.04 LTS (64Bit) with Python 3.5.

## Installation

`python setup.py install`

## Usage

In your repository dir: `pygcgen` or `python -m pygcgen`.
From elsewhere: `pygcgen -u skywinder -p ActionSheetPicker-3.0` or `python -m pygcgen -u skywinder -p ActionSheetPicker-3.0`.
